@@ -2,13 +2,14 @@ class Profile:
     def __init__(self, imi_data, imi):
         self.id = imi_data['id']
         self.name = imi_data['name']
+        self._imi = imi
 
 class Profiles:
     def __init__(self, imi, filter=None):
-        self.imi = imi
+        self._imi = imi
         self.profiles = []
-        for item in self.imi.request_items(end_of_url='profiles/'):
-            self.profiles.append(Profile(item, self.imi))
+        for item in self._imi.make_request(method='get', end_of_url='profiles/'):
+            self.profiles.append(Profile(item, self._imi))
 
     def __iter__(self):
         return iter(self.profiles)
@@ -18,4 +19,7 @@ class Profiles:
 
     def find(self, name=None):
         if name:
-            return [profile for profile in self.profiles if profile.name == name][0]
+            try:
+                return [profile for profile in self.profiles if profile.name == name][0]
+            except:
+                return None
